[![PyPI](https://img.shields.io/pypi/v/justsdk)](https://pypi.org/project/justsdk/)

# 🌊 justsdk

Just a lightweight development kit.

## Installation
```bash
pip install justsdk
```

## Usage
```python
import justsdk
```

## License
This project is under the MIT License — see the [LICENSE](https://raw.githubusercontent.com/eesuhn/eesuhn-sdk/refs/heads/main/LICENSE) file for details.
